@@ -45,7 +45,9 @@ from google.protobuf import field_mask_pb2
 from google.protobuf import timestamp_pb2
 
 
-_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution("google-cloud-asset").version
+_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution(
+    "google-cloud-asset",
+).version
 
 
 class AssetServiceClient(object):
@@ -82,7 +84,9 @@ class AssetServiceClient(object):
     def feed_path(cls, project, feed):
         """Return a fully-qualified feed string."""
         return google.api_core.path_template.expand(
-            "projects/{project}/feeds/{feed}", project=project, feed=feed
+            "projects/{project}/feeds/{feed}",
+            project=project,
+            feed=feed,
         )
 
     @classmethod
@@ -179,12 +183,14 @@ class AssetServiceClient(object):
                 self.transport = transport
         else:
             self.transport = asset_service_grpc_transport.AssetServiceGrpcTransport(
-                address=api_endpoint, channel=channel, credentials=credentials
+                address=api_endpoint,
+                channel=channel,
+                credentials=credentials,
             )
 
         if client_info is None:
             client_info = google.api_core.gapic_v1.client_info.ClientInfo(
-                gapic_version=_GAPIC_LIBRARY_VERSION
+                gapic_version=_GAPIC_LIBRARY_VERSION,
             )
         else:
             client_info.gapic_version = _GAPIC_LIBRARY_VERSION
@@ -195,7 +201,7 @@ class AssetServiceClient(object):
         # (Ordinarily, these are the defaults specified in the `*_config.py`
         # file next to this one.)
         self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
-            client_config["interfaces"][self._INTERFACE_NAME]
+            client_config["interfaces"][self._INTERFACE_NAME],
         )
 
         # Save a dictionary of cached API call functions.
@@ -205,76 +211,6 @@ class AssetServiceClient(object):
         self._inner_api_calls = {}
 
     # Service calls
-    def delete_feed(
-        self,
-        name,
-        retry=google.api_core.gapic_v1.method.DEFAULT,
-        timeout=google.api_core.gapic_v1.method.DEFAULT,
-        metadata=None,
-    ):
-        """
-        Deletes an asset feed.
-
-        Example:
-            >>> from google.cloud import asset_v1
-            >>>
-            >>> client = asset_v1.AssetServiceClient()
-            >>>
-            >>> # TODO: Initialize `name`:
-            >>> name = ''
-            >>>
-            >>> client.delete_feed(name)
-
-        Args:
-            name (str): Required. The name of the feed and it must be in the format of:
-                projects/project_number/feeds/feed_id
-                folders/folder_number/feeds/feed_id
-                organizations/organization_number/feeds/feed_id
-            retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will
-                be retried using a default configuration.
-            timeout (Optional[float]): The amount of time, in seconds, to wait
-                for the request to complete. Note that if ``retry`` is
-                specified, the timeout applies to each individual attempt.
-            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
-                that is provided to the method.
-
-        Raises:
-            google.api_core.exceptions.GoogleAPICallError: If the request
-                    failed for any reason.
-            google.api_core.exceptions.RetryError: If the request failed due
-                    to a retryable error and retry attempts failed.
-            ValueError: If the parameters are invalid.
-        """
-        # Wrap the transport method to add retry and timeout logic.
-        if "delete_feed" not in self._inner_api_calls:
-            self._inner_api_calls[
-                "delete_feed"
-            ] = google.api_core.gapic_v1.method.wrap_method(
-                self.transport.delete_feed,
-                default_retry=self._method_configs["DeleteFeed"].retry,
-                default_timeout=self._method_configs["DeleteFeed"].timeout,
-                client_info=self._client_info,
-            )
-
-        request = asset_service_pb2.DeleteFeedRequest(name=name)
-        if metadata is None:
-            metadata = []
-        metadata = list(metadata)
-        try:
-            routing_header = [("name", name)]
-        except AttributeError:
-            pass
-        else:
-            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
-                routing_header
-            )
-            metadata.append(routing_metadata)
-
-        self._inner_api_calls["delete_feed"](
-            request, retry=retry, timeout=timeout, metadata=metadata
-        )
-
     def export_assets(
         self,
         parent,
@@ -584,7 +520,9 @@ class AssetServiceClient(object):
             )
 
         request = asset_service_pb2.CreateFeedRequest(
-            parent=parent, feed_id=feed_id, feed=feed
+            parent=parent,
+            feed_id=feed_id,
+            feed=feed,
         )
         if metadata is None:
             metadata = []
@@ -658,7 +596,9 @@ class AssetServiceClient(object):
                 client_info=self._client_info,
             )
 
-        request = asset_service_pb2.GetFeedRequest(name=name)
+        request = asset_service_pb2.GetFeedRequest(
+            name=name,
+        )
         if metadata is None:
             metadata = []
         metadata = list(metadata)
@@ -730,7 +670,9 @@ class AssetServiceClient(object):
                 client_info=self._client_info,
             )
 
-        request = asset_service_pb2.ListFeedsRequest(parent=parent)
+        request = asset_service_pb2.ListFeedsRequest(
+            parent=parent,
+        )
         if metadata is None:
             metadata = []
         metadata = list(metadata)
@@ -818,7 +760,8 @@ class AssetServiceClient(object):
             )
 
         request = asset_service_pb2.UpdateFeedRequest(
-            feed=feed, update_mask=update_mask
+            feed=feed,
+            update_mask=update_mask,
         )
         if metadata is None:
             metadata = []
@@ -837,6 +780,78 @@ class AssetServiceClient(object):
             request, retry=retry, timeout=timeout, metadata=metadata
         )
 
+    def delete_feed(
+        self,
+        name,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
+        """
+        Deletes an asset feed.
+
+        Example:
+            >>> from google.cloud import asset_v1
+            >>>
+            >>> client = asset_v1.AssetServiceClient()
+            >>>
+            >>> # TODO: Initialize `name`:
+            >>> name = ''
+            >>>
+            >>> client.delete_feed(name)
+
+        Args:
+            name (str): Required. The name of the feed and it must be in the format of:
+                projects/project_number/feeds/feed_id
+                folders/folder_number/feeds/feed_id
+                organizations/organization_number/feeds/feed_id
+            retry (Optional[google.api_core.retry.Retry]):  A retry object used
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
+            timeout (Optional[float]): The amount of time, in seconds, to wait
+                for the request to complete. Note that if ``retry`` is
+                specified, the timeout applies to each individual attempt.
+            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
+                that is provided to the method.
+
+        Raises:
+            google.api_core.exceptions.GoogleAPICallError: If the request
+                    failed for any reason.
+            google.api_core.exceptions.RetryError: If the request failed due
+                    to a retryable error and retry attempts failed.
+            ValueError: If the parameters are invalid.
+        """
+        # Wrap the transport method to add retry and timeout logic.
+        if "delete_feed" not in self._inner_api_calls:
+            self._inner_api_calls[
+                "delete_feed"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.delete_feed,
+                default_retry=self._method_configs["DeleteFeed"].retry,
+                default_timeout=self._method_configs["DeleteFeed"].timeout,
+                client_info=self._client_info,
+            )
+
+        request = asset_service_pb2.DeleteFeedRequest(
+            name=name,
+        )
+        if metadata is None:
+            metadata = []
+        metadata = list(metadata)
+        try:
+            routing_header = [("name", name)]
+        except AttributeError:
+            pass
+        else:
+            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
+                routing_header
+            )
+            metadata.append(routing_metadata)
+
+        self._inner_api_calls["delete_feed"](
+            request, retry=retry, timeout=timeout, metadata=metadata
+        )
+
     def search_all_resources(
         self,
         scope,
@@ -1109,7 +1124,9 @@ class AssetServiceClient(object):
             )
 
         request = asset_service_pb2.SearchAllIamPoliciesRequest(
-            scope=scope, query=query, page_size=page_size
+            scope=scope,
+            query=query,
+            page_size=page_size,
         )
         if metadata is None:
             metadata = []
