@@ -36,7 +36,9 @@ from google.cloud.asset_v1p1beta1.proto import asset_service_pb2
 from google.cloud.asset_v1p1beta1.proto import asset_service_pb2_grpc
 
 
-_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution("google-cloud-asset").version
+_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution(
+    "google-cloud-asset",
+).version
 
 
 class AssetServiceClient(object):
@@ -156,12 +158,14 @@ class AssetServiceClient(object):
                 self.transport = transport
         else:
             self.transport = asset_service_grpc_transport.AssetServiceGrpcTransport(
-                address=api_endpoint, channel=channel, credentials=credentials
+                address=api_endpoint,
+                channel=channel,
+                credentials=credentials,
             )
 
         if client_info is None:
             client_info = google.api_core.gapic_v1.client_info.ClientInfo(
-                gapic_version=_GAPIC_LIBRARY_VERSION
+                gapic_version=_GAPIC_LIBRARY_VERSION,
             )
         else:
             client_info.gapic_version = _GAPIC_LIBRARY_VERSION
@@ -172,7 +176,7 @@ class AssetServiceClient(object):
         # (Ordinarily, these are the defaults specified in the `*_config.py`
         # file next to this one.)
         self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
-            client_config["interfaces"][self._INTERFACE_NAME]
+            client_config["interfaces"][self._INTERFACE_NAME],
         )
 
         # Save a dictionary of cached API call functions.
@@ -401,7 +405,9 @@ class AssetServiceClient(object):
             )
 
         request = asset_service_pb2.SearchAllIamPoliciesRequest(
-            scope=scope, query=query, page_size=page_size
+            scope=scope,
+            query=query,
+            page_size=page_size,
         )
         if metadata is None:
             metadata = []
